require 'image_size'

class ImageSizeCache < ImageSize

  # Cache width and height by inode
  @@cache = Hash.new

  def ImageSizeCache.open(filename)
    stat  = File.stat(filename)
    inode = stat.ino
    if @@cache[inode]
      #puts "hit"
      cached = new("")
      cached.inode = inode
      return cached
    end

    #puts "missed"
    File.open(filename) { |fh| 
      cached = new(fh)
      @@cache[inode] = [ cached.get_width, cached.get_height ]
      cached.inode = inode   # once the inode is set, cached? with return true
    }
    return cached
  end

  def initialize(text)
    super(text)
    @inode = nil
  end

  attr_writer :inode

  def get_width
    return @@cache[@inode][0] if @inode != nil
    return super
  end

  def get_height
    return @@cache[@inode][1] if @inode != nil
    return super
  end

  def get_dimensions
    return @@cache[@inode] if @inode != nil
    return [ get_width, get_height ]
  end

end
