#!/share/usr/bin/ruby -w

require 'getoptlong'

require 'findbin'
$:.push FindBin::RealBin

require 'album'
require 'rp_debug'
include Debug

$VERSION = '0.10'
def usage(text = nil)
  puts text + "\n\n" if text

  print <<EOF
Usage: #{FindBin::Script} [ OPTION ... ] [ IMAGE-ROOT [ RELATIVE-SUBDIRS ... ] ]
Options:
 -a, --albums       only generate albums\' HTML; skip photo generation
 -n, --html         only generate HTML; skip photo scaling (except thumbnails)
 -t, --tree         only generate the tree page
 -V, --version      output version information and exit
 -v, --verbosity=N  change verbosity level, 0 is no output [#{verbosity}]
 -c, --config=FILE  specify config file [~/.rubyphoto.conf]
 -h, --help         display this help and exit
EOF
end  

def main
  arg_parser = GetoptLong.new
  arg_parser.set_options(
    [ '--albums',    '-a', GetoptLong::NO_ARGUMENT       ],
    [ '--html',      '-n', GetoptLong::NO_ARGUMENT       ],
    [ '--tree',      '-t', GetoptLong::NO_ARGUMENT       ],
    [ '--version',   '-V', GetoptLong::NO_ARGUMENT       ],
    [ '--verbosity', '-v', GetoptLong::REQUIRED_ARGUMENT ],
    [ '--config',    '-c', GetoptLong::REQUIRED_ARGUMENT ],
    [ '--help',      '-h', GetoptLong::NO_ARGUMENT       ]
  )

  $config_file = ENV['HOME'] + '/.rubyphoto-conf'
  $albums_only = false
  $tree_only   = false
  $html_only   = false

  begin
    arg_parser.each do |optname, optarg|
      case optname
      when '--help'
        usage
        exit 0
      when '--version'
        puts FindBin::Script + " #$VERSION"
        exit 0
      when '--verbosity'
        Debug.verbosity = optarg.to_i
      when '--config'
        $config_file = optarg
      when '--albums'
        $albums_only = true
      when '--tree'
        $tree_only = true
      when '--html'
        $html_only = true
      else
        raise "Got weird option #{optname}"
      end
    end
  rescue
    usage
    exit 1
  end

  ARGV.unshift(ENV['RUBYPHOTO_ROOTDIR']) if ENV['RUBYPHOTO_ROOTDIR']
  $input_dir = ARGV[0] || '.'

  if ! test(?d, $input_dir)
    usage $input_dir + " isn't a valid directory."
    exit 1
  end

  debug 1, "Scanning directory structure ... "
  album = Album.new($input_dir)

  album.output_tree_html
  debug 1, "Tree"

  return if $tree_only

  if ARGV.length >= 2
    ARGV[1 .. -1].each { |subdir|
      subdir[-1] = '' if subdir[-1] == ?/
      subalbum = album.rec_find_album_by_path(subdir)
      raise "No such subalbum with path `#{subdir}'" unless subalbum
      subalbum.output_html
    }
  else
    album.output_html
  end
end

main
